pub struct OpaqueType {
pub rust_path: String,
pub opaque_name: String,
}Expand description
One source type and the opaque struct identifier generated for it.
Fields
rust_path: StringRust type expression as visible from the probe crate.
opaque_name: StringEmitted opaque struct identifier.
Implementations